# ThreeDSecureDataV1AllOf


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**authentication_response** | **str** | The authentication response. | 
**cavv_algorithm** | **str** | The CAVV Algorithm used. | 
**xid** | **str** | The transaction identifier. | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


